@@ -20,7 +20,6 @@ OC.L10N.register(
     "Restore" : "Geri qaytar",
     "Delete permanently" : "Həmişəlik sil",
     "Share link" : "Linki yayımla",
-    "can edit" : "dəyişmək olar",
     "Save" : "Saxla",
     "Cancel" : "Dayandır",
     "Automatic" : "Avtomatik",
@@ -50,6 +49,7 @@ OC.L10N.register(
     "Done" : "Edildi",
     "Accept" : "Qəbul et",
     "Decline" : "İmtina",
+    "Copied to clipboard" : "Mübadilə buferinə nüsxələndi",
     "Attendees" : "İştirakçılar",
     "Remove group" : "Qrupu sil",
     "Repeat" : "Təkrar",
@@ -68,6 +68,7 @@ OC.L10N.register(
     "Other" : "Digər",
     "Status" : "Status",
     "Categories" : "Kateqoriyalar",
-    "Hidden" : "Gizli"
+    "Hidden" : "Gizli",
+    "can edit" : "dəyişmək olar"
 },
 "nplurals=2; plural=(n != 1);");
