@@ -6,7 +6,6 @@ OC.L10N.register(
     "No upcoming events" : "Няма будучых падзей",
     "%1$s with %2$s" : "%1$s з %2$s",
     "Calendar" : "Каляндар",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Confirm" : "Пацвердзіць",
     "Description:" : "Апісанне:",
     "Date:" : "Дата:",
@@ -14,6 +13,7 @@ OC.L10N.register(
     "Where:" : "Дзе:",
     "Comment:" : "Каментарый:",
     "Location:" : "Месцазнаходжанне:",
+    "%1$s minutes" : "%1$s хв",
     "Duration:" : "Працягласць:",
     "%1$s from %2$s to %3$s" : "%1$s з %2$s да %3$s",
     "Dates:" : "Даты:",
@@ -37,6 +37,7 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Уключыць каляндар \"{calendar}\"",
     "Enable untitled calendar" : "Уключыць каляндар без назвы",
     "Untitled calendar" : "Каляндар без назвы",
+    "Copy public link" : "Скапіяваць публічную спасылку",
     "Edit calendar" : "Рэдагаваць каляндар",
     "Calendars" : "Календары",
     "New calendar with task list" : "Новы каляндар са спісам заданняў",
@@ -49,7 +50,6 @@ OC.L10N.register(
     "Shared calendars" : "Абагуленыя календары",
     "Internal link" : "Унутраная спасылка",
     "Share link" : "Абагуліць спасылку",
-    "Copy public link" : "Скапіяваць публічную спасылку",
     "Unshare with {displayName}" : "Скасаваць абагульванне з {displayName}",
     "No users or groups" : "Няма карыстальнікаў або груп",
     "Unshare from me" : "Скасаваць абагульванне са мной",
@@ -62,6 +62,7 @@ OC.L10N.register(
     "Navigation" : "Навігацыя",
     "Actions" : "Дзеянні",
     "Close editor" : "Закрыць рэдактар",
+    "or" : "або",
     "General" : "Агульныя",
     "Availability settings" : "Налады даступнасці",
     "CalDAV" : "CalDAV",
@@ -72,7 +73,7 @@ OC.L10N.register(
     "Tasks in calendar" : "Заданні ў календары",
     "Weekends" : "Уік-энды",
     "Week numbers" : "Нумары тыдняў",
-    "Keyboard shortcuts" : "Спалучэнні клавіш",
+    "Files" : "Файлы",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} хвіліна","{duration} хвіліны","{duration} хвілін","{duration} хвілін"],
     "_{duration} hour_::_{duration} hours_" : ["{duration} гадзіна","{duration} гадзіны","{duration} гадзін","{duration} гадзін"],
     "_{duration} day_::_{duration} days_" : ["{duration} дзень","{duration} дні","{duration} дзён","{duration} дзён"],
@@ -80,6 +81,7 @@ OC.L10N.register(
     "_{duration} month_::_{duration} months_" : ["{duration} месяц","{duration} месяцы","{duration} месяцаў","{duration} месяцаў"],
     "_{duration} year_::_{duration} years_" : ["{duration} год","{duration} гады","{duration} гадоў","{duration} гадоў"],
     "Update" : "Абнавіць",
+    "(copy)" : "(копія)",
     "Location" : "Месцазнаходжанне",
     "Description" : "Апісанне",
     "Visibility" : "Бачнасць",
@@ -105,6 +107,7 @@ OC.L10N.register(
     "Upload from device" : "Запампаваць з прылады",
     "Delete file" : "Выдаліць файл",
     "Confirmation" : "Пацвярджэнне",
+    "_{count} attachment_::_{count} attachments_" : ["{count} далучэнне","{count} далучэнні","{count} далучэнняў","{count} далучэнняў"],
     "Accepted {organizerName}'s invitation" : "Прынята запрашэнне {organizerName}",
     "Declined {organizerName}'s invitation" : "Адхілена запрашэнне {organizerName}",
     "{organizer} (organizer)" : "{organizer} (арганізатар)",
@@ -117,8 +120,8 @@ OC.L10N.register(
     "Unknown" : "Невядомы",
     "Accept" : "Прыняць",
     "Decline" : "Адхіліць",
+    "Copied to clipboard" : "Скапіявана ў буфер абмену",
     "No attendees yet" : "Пакуль няма ўдзельнікаў",
-    "Successfully appended link to talk room to description." : "Спасылка на пакой у Talk паспяхова дададзена ў апісанне.",
     "Attendees" : "Удзельнікі",
     "Remove group" : "Выдаліць групу",
     "Remove attendee" : "Выдаліць удзельніка",
@@ -146,6 +149,7 @@ OC.L10N.register(
     "Show unscheduled tasks" : "Паказаць незапланаваныя заданні",
     "Unscheduled tasks" : "Незапланаваныя заданні",
     "Availability of {displayName}" : "Даступнасць {displayName}",
+    "Discard changes" : "Адхіліць змены",
     "All day" : "Увесь дзень",
     "Invite" : "Запрасіць",
     "Discard changes?" : "Адхіліць змены?",
@@ -183,10 +187,12 @@ OC.L10N.register(
     "Categories" : "Катэгорыі",
     "Error while sharing file" : "Памылка пры абагульванні файла",
     "User not found" : "Карыстальнік не знойдзены",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Calendar name …" : "Назва календара …",
     "Enable birthday calendar" : "Уключыць каляндар дзён нараджэння",
     "Show tasks in calendar" : "Паказаць заданні ў календары",
     "Show weekends" : "Паказваць уік-энды",
-    "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш"
+    "Show keyboard shortcuts" : "Паказаць спалучэнні клавіш",
+    "Successfully appended link to talk room to description." : "Спасылка на пакой у Talk паспяхова дададзена ў апісанне."
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
