@@ -17,13 +17,11 @@ OC.L10N.register(
     "Deleted" : "মুছে ফেলা",
     "Restore" : "ফিরিয়ে দাও",
     "Share link" : "লিংক ভাগাভাগি করেন",
-    "can edit" : "সম্পাদনা করতে পারবেন",
     "Save" : "সংরক্ষণ",
     "Cancel" : "বাতিল",
     "Automatic" : "স্বয়ংক্রিয়",
     "Actions" : "পদক্ষেপসমূহ",
     "General" : "সাধারণ",
-    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
     "Update" : "পরিবর্ধন",
     "Location" : "অবস্থান",
     "Description" : "বিবরণ",
@@ -47,6 +45,7 @@ OC.L10N.register(
     "Choose a file to add as attachment" : "সংযুক্তি দেয়ার জন্য একটি ফাইল নির্বাচন করুন",
     "Done" : "শেষ হলো",
     "Unknown" : "অজানা",
+    "Copied to clipboard" : "ক্লিপবোর্ডে কপি করা হলো",
     "Attendees" : "অংশগ্রহণকারীবৃন্দ",
     "Repeat" : "পূনঃসংঘটন",
     "never" : "কখনোই নয়",
@@ -61,6 +60,7 @@ OC.L10N.register(
     "Weekly" : "সাপ্তাহিক",
     "second" : "সেকেন্ড",
     "Other" : "অন্যান্য",
-    "Hidden" : "লুকনো"
+    "Hidden" : "লুকনো",
+    "can edit" : "সম্পাদনা করতে পারবেন"
 },
 "nplurals=2; plural=(n != 1);");
