@@ -32,8 +32,11 @@ OC.L10N.register(
     "Delete" : "Dilemel",
     "Create new" : "Krouiñ unan nevez",
     "An error occurred, unable to change visibility of the calendar." : "C'hoarvezet ez eus ur fazi, ne c'halletr ket kemmañ gweluster an deiziataer.",
+    "Calendar link copied to clipboard." : "Eilet eo bet liamm an deiziataer er golver",
+    "Calendar link could not be copied to clipboard." : "N'eus ket bet gallet eilañ liamm an deiziataer er golver",
     "Untitled calendar" : "Deiziataer hep titl",
     "Shared with you by" : "Rannet deoc'h gant",
+    "Copy public link" : "Eilañ al liamm foran",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Paouezet e vo da lodañ an deiziataer a-benn {countdown} eilenn"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dirannañ an deizataer a ben {countdown} eilenn","Dilamet e vo an deiziataer a-benn {countdown} eilenn"],
     "An error occurred, unable to create the calendar." : "Ur fazi a zo bet, dibosupl eo krouiñ an deizataer",
@@ -44,8 +47,6 @@ OC.L10N.register(
     "New calendar with task list" : "Deizataer nevez gant ur roll ober",
     "New subscription from link (read-only)" : "Koumanant nevez dre liamm (lenn nemetken)",
     "Creating subscription …" : "Krouiñ ur goumanant ...",
-    "Calendar link copied to clipboard." : "Eilet eo bet liamm an deiziataer er golver",
-    "Calendar link could not be copied to clipboard." : "N'eus ket bet gallet eilañ liamm an deiziataer er golver",
     "Copy subscription link" : "Eilañ al liamm koumanantiñ",
     "Copying link …" : "Oc'h eilañ al liamm  ...",
     "Copied link" : "Liamm eilet",
@@ -62,7 +63,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "N'eus ket bet gallet eilañ ar c'hod enframmañ er golver.",
     "Unpublishing calendar failed" : "Diembannaadur an deizataer c'hwited",
     "Share link" : "Lodañ al liamm",
-    "Copy public link" : "Eilañ al liamm foran",
     "Send link to calendar via email" : "Kas al liamm d'an deiziataer dre bostel",
     "Enter one address" : "Lakait ur chomlec'h",
     "Sending email …" : "O kas ar postel  ... ",
@@ -73,7 +73,6 @@ OC.L10N.register(
     "Delete share link" : "Dilamet eo bet al liamm lodañ",
     "Deleting share link …" : "O tilemel al liamm lodañ...",
     "An error occurred, unable to change the permission of the share." : "Ur azi a zo bet, dibosupl eo cheñch aotreoù ar rannadenn.",
-    "can edit" : "posuple eo embann",
     "Unshare with {displayName}" : "Dirannañ gant {displayName}",
     "Share with users or groups" : "Rannañ gant implijourienn pe strolladoù",
     "No users or groups" : "Implijourienn pe strodadoù ebet",
@@ -86,6 +85,7 @@ OC.L10N.register(
     "Calendar to import into" : "Deizataer de emporzhiañ e-barzh",
     "Cancel" : "Nullañ",
     "_Import calendar_::_Import calendars_" : ["Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer","Emporzhiañ deizataer"],
+    "Attachments folder" : "Teuliad stag",
     "{filename} could not be parsed" : "{filename} na c'hell ket bezhañ dielfennet",
     "No valid files found, aborting import" : "Restr mat kavet ebet, arrestet e vez an emporzhiañ",
     "Import partially failed. Imported {accepted} out of {total}." : "Emporzhiañ damc'hwitet. Emporzhiet {accepted} diwar {total}.",
@@ -116,6 +116,7 @@ OC.L10N.register(
     "Unknown" : "Dianv",
     "Accept" : "Asantiñ",
     "Tentative" : "Taol-esae",
+    "Copied to clipboard" : "Eilet er golver",
     "Remove group" : "Lemel strollad",
     "never" : "james",
     "after" : "goude",
@@ -149,7 +150,6 @@ OC.L10N.register(
     "When shared show full event" : "Diskouez an darvoud a-bezh pa vez lodet",
     "When shared show only busy" : "Diskouez hepken ar re pres warno pa vez lodet",
     "When shared hide this event" : "Kuzhat an darvoud-mañ pa vez lodet",
-    "The visibility of this event in shared calendars." : "Gweluster an darvoud-mañ en deiziataerioù lodet.",
     "Add a location" : "Ouzhpennañ ul lec'hiadur",
     "Status" : "Statud",
     "Confirmed" : "Kadarnaet",
@@ -166,6 +166,8 @@ OC.L10N.register(
     "Error while sharing file" : "Ur fazi a zo bet en ur rannañ ar restr",
     "An error occurred, unable to delete the calendar." : "C'hoarvezet ez eus ur fazi, ne c'haller ket dilemel an deiziataer.",
     "Imported {filename}" : "Enporzhiet {filename}",
-    "Hidden" : "Koachet"
+    "Hidden" : "Koachet",
+    "can edit" : "posuple eo embann",
+    "The visibility of this event in shared calendars." : "Gweluster an darvoud-mañ en deiziataerioù lodet."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
