@@ -64,6 +64,7 @@ OC.L10N.register(
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
     "Tentative" : "Tentativo",
+    "Copied to clipboard" : "Copiado al portapapeles",
     "Attendees" : "Asistentes",
     "Repeat" : "Repetir",
     "never" : "nunca",
@@ -94,7 +95,6 @@ OC.L10N.register(
     "User not found" : "No se encontró el usuario",
     "Hidden" : "Oculto",
     "can edit" : "puede editar",
-    "Show week numbers" : "Mostrar número de semana",
-    "Keyboard shortcuts" : "Atajos del teclado"
+    "Show week numbers" : "Mostrar número de semana"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
