@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "قرارها",
     "Schedule appointment \"%s\"" : "Schedule appointment \"%s\"",
     "Schedule an appointment" : "Schedule an appointment",
-    "%1$s - %2$s" : "%1$s - %2$s",
     "Prepare for %s" : "Prepare for %s",
     "Follow up for %s" : "Follow up for %s",
     "Your appointment \"%s\" with %s needs confirmation" : "Your appointment \"%s\" with %s needs confirmation",
@@ -60,6 +59,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Appointment link could not be copied to clipboard",
     "Preview" : "پیش‌نمایش",
     "Copy link" : "کپی کردن لینک",
+    "Duplicate" : "Duplicate",
     "Edit" : "ویرایش",
     "Delete" : "حذف",
     "Create new" : "ایجاد جدید",
@@ -68,8 +68,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Enable calendar \"{calendar}\"",
     "Enable untitled calendar" : "Enable untitled calendar",
     "An error occurred, unable to change visibility of the calendar." : "خطایی روی داد ، قادر به تغییر دیدگاه تقویم نیست.",
+    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
+    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
     "Untitled calendar" : "تقویم بدون عنوان",
     "Shared with you by" : "با شما به اشتراک گذاشته شده است",
+    "Copy public link" : "پیوند عمومی را کپی کنید",
     "Edit and share calendar" : "Edit and share calendar",
     "Edit calendar" : "ویرایش تقویم",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه","اشتراک‌گذاری تقویم در {شمارش معکوس}. ثانیه ها"],
@@ -85,8 +88,6 @@ OC.L10N.register(
     "New subscription from link (read-only)" : "اشتراک جدید از پیوند (فقط خواندنی)",
     "Creating subscription …" : "ایجاد اشتراک…",
     "Add public holiday calendar" : "Add public holiday calendar",
-    "Calendar link copied to clipboard." : "پیوند تقویم در کلیپ بورد کپی شد.",
-    "Calendar link could not be copied to clipboard." : "پیوند تقویم را نمی توان در کلیپ بورد کپی کرد.",
     "Copy subscription link" : "پیوند اشتراک را کپی کنید",
     "Copying link …" : "کپی پیوند ...",
     "Copied link" : "پیوند کپی شد",
@@ -118,7 +119,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "کد جاسازی را نمی توان در کلیپ بورد کپی کرد.",
     "Unpublishing calendar failed" : "عدم انتشار تقویم موفقیت آمیز نبود",
     "Share link" : "لینک را به اشتراک بگذارید",
-    "Copy public link" : "پیوند عمومی را کپی کنید",
     "Send link to calendar via email" : "ارسال پیوند به تقویم از طریق ایمیل",
     "Enter one address" : "یک آدرس وارد کنید",
     "Sending email …" : "ارسال ایمیل…",
@@ -193,6 +193,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "عمومی – در صفحهٔ نمایه نشان داده می‌شود",
     "Private – only accessible via secret link" : "Private – only accessible via secret link",
     "Update" : "به روز رسانی",
+    "(copy)" : "(کپی)",
     "Appointment name" : "Appointment name",
     "Location" : "مکان",
     "Create a Talk room" : "ایجاد اتاق گفتگو",
@@ -287,6 +288,7 @@ OC.L10N.register(
     "Accept" : "تایید",
     "Decline" : "کاهش می یابد",
     "Tentative" : "آزمایشی",
+    "Copied to clipboard" : "در حافظه رونویسی شد",
     "No attendees yet" : "هنوز هیچ حضوری وجود ندارد",
     "Attendees" : "شرکت کنندگان",
     "Remove group" : "برداشتن گروه",
@@ -370,6 +372,7 @@ OC.L10N.register(
     "By {authors}" : "By {authors}",
     "Subscribed" : "Subscribed",
     "Subscribe" : "اشتراک گذاری",
+    "Select a date" : "تاریخ را انتخاب کنید",
     "Select slot" : "Select slot",
     "No slots available" : "No slots available",
     "The slot for your appointment has been confirmed" : "The slot for your appointment has been confirmed",
@@ -386,9 +389,9 @@ OC.L10N.register(
     "Personal" : "شخصی",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue.",
+    "Discard changes" : "Discard changes",
     "Edit event" : "ویرایش رویداد",
     "Event does not exist" : "رویداد وجود ندارد",
-    "Duplicate" : "Duplicate",
     "Delete this occurrence" : "این رخداد را حذف کنید",
     "Delete this and all future" : "این و همه آینده را حذف کنید",
     "All day" : "تمام روز",
@@ -399,6 +402,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Attachment requires shared access","Attachments requiring shared access"],
     "Untitled event" : "رویداد بدون عنوان",
     "Close" : "بستن",
+    "This event was cancelled" : "This event was cancelled",
     "Title" : "Title",
     "30 min" : "30 min",
     "Participants" : "شركت كنندگان",
@@ -492,6 +496,7 @@ OC.L10N.register(
     "This is an event reminder." : "This is an event reminder.",
     "Appointment not found" : "Appointment not found",
     "User not found" : "کاربر یافت نشد",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "مخفی",
     "can edit" : "می توان ویرایش کرد",
     "Calendar name …" : "نام تقویم …",
@@ -514,7 +519,6 @@ OC.L10N.register(
     "Successfully appended link to talk room to location." : "Successfully appended link to talk room to location.",
     "Successfully appended link to talk room to description." : "پیوند موفقیت آمیز پیوند به اتاق گفتگو به توضیحات.",
     "Error creating Talk room" : "خطا در ایجاد اتاق گفتگو",
-    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک.",
-    "Keyboard shortcuts" : "میان‌برهای صفحه‌کلید"
+    "The visibility of this event in shared calendars." : "قابلیت مشاهده این رویداد در تقویمهای مشترک."
 },
 "nplurals=2; plural=(n > 1);");
