@@ -21,7 +21,7 @@ OC.L10N.register(
     "Appointments" : "Tapaamiset",
     "Schedule appointment \"%s\"" : "Ajoita tapaaminen \"%s\"",
     "Schedule an appointment" : "Ajoita tapaaminen",
-    "%1$s - %2$s" : "%1$s - %2$s",
+    "Appointment Description:" : "Tapaamisen kuvaus:",
     "Prepare for %s" : "Valmistaudu tapahtumaan \"%s\"",
     "Your appointment \"%s\" with %s needs confirmation" : "Tapaaminen \"%s\"  henkilön %s kanssa vaatii vahvistamisen",
     "Dear %s, please confirm your booking" : "%s, ole hyvä ja vahvista varauksesi",
@@ -44,9 +44,12 @@ OC.L10N.register(
     "Dear %s, a proposed meeting has been updated" : "%s, ehdotettu kokous on päivitetty",
     "Dear %s, a proposed meeting has been cancelled" : "%s, ehdotettu kokous on peruttu",
     "Location:" : "Sijainti:",
+    "%1$s minutes" : "%1$s minuuttia",
     "Duration:" : "Kesto:",
     "Dates:" : "Päivät:",
     "Respond" : "Vastaa",
+    "[Proposed] %1$s" : "[Ehdotettu] %1$s",
+    "Calendar App" : "Kalenterisovellus",
     "A Calendar app for Nextcloud" : "Kalenterisovellus Nextcloudille",
     "Previous day" : "Edellinen päivä",
     "Previous week" : "Edellinen viikko",
@@ -77,8 +80,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Ota käyttöön kalenteri \"{calendar}\"",
     "Enable untitled calendar" : "Ota nimetön kalenteri käyttöön",
     "An error occurred, unable to change visibility of the calendar." : "Tapahtui virhe. Kalenterin näkyvyyttä ei voitu muuttaa.",
+    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
+    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
     "Untitled calendar" : "Nimetön kalenteri",
     "Shared with you by" : "Jaettu sinulle käyttäjältä",
+    "Copy public link" : "Kopioi julkinen linkki",
     "Edit and share calendar" : "Muokkaa/jaa kalenteri",
     "Edit calendar" : "Muokkaa kalenteria",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Poistetaan kalenterin jako {countdown} sekunnin kuluttua","Poistetaan kalenterin jako {countdown} sekunnin kuluttua"],
@@ -95,8 +101,6 @@ OC.L10N.register(
     "Creating subscription …" : "Luodaan tilaus …",
     "Add public holiday calendar" : "Lisää juhlapäiväkalenteri",
     "Add custom public calendar" : "Lisää mukautettu julkinen kalenteri",
-    "Calendar link copied to clipboard." : "Kalenterilinkki kopioitu leikepöydälle.",
-    "Calendar link could not be copied to clipboard." : "Kalenterilinkkiä ei voitu kopioida leikepöydälle.",
     "Copy subscription link" : "Kopioi tilauslinkki",
     "Copying link …" : "Kopioidaan linkki …",
     "Copied link" : "Linkki kopioitu",
@@ -129,7 +133,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Upotuskoodia ei voitu kopioida leikepöydälle.",
     "Unpublishing calendar failed" : "Kalenterin julkaisun peruminen epäonnistui",
     "Share link" : "Jaa linkki",
-    "Copy public link" : "Kopioi julkinen linkki",
     "Send link to calendar via email" : "Lähetä kalenteriin johtava linkki sähköpostitse",
     "Enter one address" : "Kirjoita yksi osoite",
     "Sending email …" : "Lähetetään sähköpostia …",
@@ -146,6 +149,8 @@ OC.L10N.register(
     "Share with users or groups" : "Jaa käyttäjien tai ryhmien kanssa",
     "No users or groups" : "Ei käyttäjiä tai ryhmiä",
     "Failed to save calendar name and color" : "Kalenterin nimen ja värin tallentaminen epäonnistui",
+    "Calendar name …" : "Kalenterin nimi …",
+    "Never show me as busy (set this calendar to transparent)" : "Älä ikinä näytä minua varattuna (aseta tämä kalenteri läpinäkyväksi)",
     "Share calendar" : "Jaa kalenteri",
     "Unshare from me" : "Lopeta jako minulle",
     "Save" : "Tallenna",
@@ -201,8 +206,20 @@ OC.L10N.register(
     "No reminder" : "Ei muistutusta",
     "Failed to save default calendar" : "Oletuskalenterin tallentaminen epäonnistui",
     "General" : "Yleiset",
+    "Availability settings" : "Saatavuuden asetukset",
+    "CalDAV" : "CalDAV",
+    "Access Nextcloud calendars from other apps and devices" : "Käytä Nextcloud-kalentereita muista sovelluksista ja laitteilta",
+    "CalDAV URL" : "CalDAV:in URL-osoite",
+    "Server Address for iOS and macOS" : "Palvelinosoite iOS:lle ja macOS:lle",
     "Appearance" : "Ulkoasu",
+    "Birthday calendar" : "Syntymäpäiväkalenteri",
+    "Tasks in calendar" : "Tehtävät kalenterissa",
+    "Weekends" : "Viikonloput",
+    "Week numbers" : "Viikkonumerot",
+    "Limit number of events shown in Month view" : "Rajoita kuukausinäkymässä näytettävien tapahtumien määrää",
+    "Editing" : "Muokkaaminen",
     "Default reminder" : "Oletusmuistutus",
+    "Simple event editor" : "Yksinkertainen tapahtumamuokkain",
     "Files" : "Tiedostot",
     "_{duration} minute_::_{duration} minutes_" : ["{duration} minuutti","{duration} minuuttia"],
     "0 minutes" : "0 minuuttia",
@@ -218,6 +235,7 @@ OC.L10N.register(
     "Create appointment schedule" : "Luo tapaamisaikataulu",
     "Edit appointment schedule" : "Muokkaa tapaamisaikataulua",
     "Update" : "Päivitä",
+    "(copy)" : "(kopioi)",
     "Appointment name" : "Tapaamisen nimi",
     "Location" : "Sijainti",
     "Create a Talk room" : "Luo Talk-huone",
@@ -262,10 +280,13 @@ OC.L10N.register(
     "Talk conversation for event" : "Tapahtuman Talk-keskustelu",
     "Error creating Talk conversation" : "Virhe luotaessa Talk-keskustelua",
     "Select a Talk Room" : "Valitse Talk-huone",
-    "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Fetching Talk rooms…" : "Noudetaan Talk-huoneita…",
     "No Talk room available" : "Talk-huonetta ei ole käytettävissä",
+    "Select existing conversation" : "Valitse olemassa oleva keskustelu",
     "Select conversation" : "Valitse keskustelu",
+    "Or create a new conversation" : "Tai luo uusi keskustelu",
+    "Create public conversation" : "Luo julkinen keskustelu",
+    "Create private conversation" : "Luo yksityinen keskustelu",
     "on" : "päivä",
     "at" : "kellonaika",
     "before at" : "ennen",
@@ -325,6 +346,7 @@ OC.L10N.register(
     "Legend" : "Selite",
     "Out of office" : "Ulkona toimistolta",
     "Attendees:" : "Osallistujat:",
+    "local time" : "paikallinen aika",
     "Done" : "Valmis",
     "Search room" : "Etsi huonetta",
     "Room name" : "Huoneen nimi",
@@ -343,6 +365,9 @@ OC.L10N.register(
     "Accept" : "Hyväksy",
     "Decline" : "Kieltäydy",
     "Tentative" : "Alustava",
+    "Copied to clipboard" : "Kopioitu leikepöydälle",
+    "Failed to copy" : "Kopiointi epäonnistui",
+    "Copy name and email address" : "Kopioi nimi ja sähköpostiosoite",
     "No attendees yet" : "Ei vielä osallistujia",
     "Attendees" : "Osallistujat",
     "Remove group" : "Poista ryhmä",
@@ -457,12 +482,13 @@ OC.L10N.register(
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Asettamaasi aikavyöhykettä ({timezoneId}) ei löytynyt. Vaihdetaan takaisin UTC:hen.\nOle hyvä ja vaihda aikavyöhykkeesi asetuksista ja ilmoita tästä ongelmasta.",
     "Show unscheduled tasks" : "Näytä ajastamattomat tehtävät",
     "Unscheduled tasks" : "Ajastamattomat tehtävät",
-    "Discard event" : "Hylkää tapahtuma",
+    "Discard changes" : "Hylkää muutokset",
     "Edit event" : "Muokkaa tapahtumaa",
     "Event does not exist" : "Tapahtumaa ei ole olemassa",
     "Delete this occurrence" : "Poista tämä esiintymä",
     "Delete this and all future" : "Poista tämä ja kaikki tulevat",
     "All day" : "Koko päivä",
+    "Add Talk conversation" : "Lisää Talk-keskustelu",
     "Managing shared access" : "Jaetun pääsyn hallinta",
     "Deny access" : "Estä pääsy",
     "Invite" : "Kutsu",
@@ -471,6 +497,7 @@ OC.L10N.register(
     "_User requires access to your file_::_Users require access to your file_" : ["Käyttäjä tarvitsee pääsyn tiedostoosi","Käyttäjät tarvitsevat pääsyn tiedostoosi"],
     "Untitled event" : "Nimetön tapahtuma",
     "Close" : "Sulje",
+    "This event was cancelled" : "Tämä tapahtuma peruttiin",
     "Meeting proposals overview" : "Kokousehdotusten yhteenveto",
     "Edit meeting proposal" : "Muokkaa kokousehdotusta",
     "Create meeting proposal" : "Luo kokousehdotus",
@@ -493,6 +520,8 @@ OC.L10N.register(
     "90 min" : "90 min",
     "Participants" : "Osallistujat",
     "Selected times" : "Valitut ajat",
+    "Less days" : "Vähemmän päiviä",
+    "More days" : "Enemmän päiviä",
     "Loading meeting proposal" : "Ladataan kokousehdotusta",
     "No meeting proposal found" : "Kokousehdotusta ei löytynyt",
     "Thank you for your response!" : "Kiitos vastauksestasi!",
@@ -553,6 +582,7 @@ OC.L10N.register(
     "last" : "viimeinen",
     "Untitled task" : "Nimetön tehtävä",
     "Please ask your administrator to enable the Tasks App." : "Pyydä järjestelmänvalvojaa ottamaan Tasks-sovellus käyttöön",
+    "You are not allowed to edit this event as an attendee." : "Sinulla ei ole oikeutta muokata tätä tapahtumaa osallistujan roolissa.",
     "W" : "Vko",
     "%n more" : "%n lisää",
     "No events to display" : "Ei tapahtumia näytettäväksi",
@@ -600,6 +630,7 @@ OC.L10N.register(
     "This is an event reminder." : "Tämä on tapahtuman muistutus.",
     "Appointment not found" : "Tapaamista ei löydy",
     "User not found" : "Käyttäjää ei löydy",
+    "%1$s - %2$s" : "%1$s - %2$s",
     "Hidden" : "Piilotettu",
     "can edit" : "voi muokata",
     "Calendar name …" : "Kalenterin nimi…",
