@@ -72,8 +72,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "\"{calendar}\" カレンダーを有効化する",
     "Enable untitled calendar" : "無題のカレンダーを有効にする",
     "An error occurred, unable to change visibility of the calendar." : "エラーが発生したため、カレンダーの表示状態を変更できません。",
+    "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
+    "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
     "Untitled calendar" : "無題のカレンダー",
     "Shared with you by" : "と共有中",
+    "Copy public link" : "公開リンクをコピー",
     "Edit and share calendar" : "カレンダー編集、共有",
     "Edit calendar" : "カレンダー編集",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}秒後にカレンダーの共有を解除します"],
@@ -90,8 +93,6 @@ OC.L10N.register(
     "Creating subscription …" : "購読を作成中 …",
     "Add public holiday calendar" : "祝日カレンダーを追加",
     "Add custom public calendar" : "カスタム公開カレンダーを追加する",
-    "Calendar link copied to clipboard." : "カレンダーリンクをクリップボードにコピー",
-    "Calendar link could not be copied to clipboard." : "カレンダーリンクをクリップボードにコピーできませんでした。",
     "Copy subscription link" : "購読リンクをコピー",
     "Copying link …" : "リンクをコピーしています …",
     "Copied link" : "リンクをコピーしました",
@@ -123,7 +124,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "埋め込みコードをクリップボードにコピーできませんでした。",
     "Unpublishing calendar failed" : "カレンダーの公開解除に失敗しました",
     "Share link" : "URLで共有",
-    "Copy public link" : "公開リンクをコピー",
     "Send link to calendar via email" : "メールでカレンダーへのリンクを送信",
     "Enter one address" : "アドレスを1つ入力してください",
     "Sending email …" : "メールを送信中 …",
@@ -430,7 +430,7 @@ OC.L10N.register(
     "Personal" : "個人",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "自動的なタイムゾーンの検出により、あなたのタイムゾーンはUTCと判断されました。\nこれはおそらく、あなたのウェブブラウザのセキュリティ対策の結果です。\nカレンダーの設定でタイムゾーンを手動で設定してください。",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "設定されたタイムゾーン ({timezoneId}) が見つかりませんでした。UTCにフォールバックします。\n設定でタイムゾーンを変更して、この問題を報告してください。",
-    "Discard event" : "イベントを破棄",
+    "Discard changes" : "変更を破棄する",
     "Edit event" : "イベントを編集",
     "Event does not exist" : "イベントは存在しません",
     "Delete this occurrence" : "この出来事を削除",
@@ -445,6 +445,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["添付ファイルには共有アクセスが必要です"],
     "Untitled event" : "無題のイベント",
     "Close" : "閉じる",
+    "This event was cancelled" : "このイベントはキャンセルされました",
     "Selected" : "選択済み",
     "Title" : "タイトル",
     "30 min" : "30分",
