@@ -41,7 +41,6 @@ OC.L10N.register(
     "or" : "neɣ",
     "General" : "Amatu",
     "Appearance" : "Udem",
-    "Keyboard shortcuts" : "Inegzumen n unasiw",
     "Location" : "Adig",
     "Description" : "Aglam",
     "Add" : "Rnu",
@@ -62,6 +61,7 @@ OC.L10N.register(
     "Done" : "Immed",
     "Busy" : "Ur yestuf ara",
     "Unknown" : "Arussin",
+    "Copied to clipboard" : "Aḍris yettwanγel γef afus",
     "Yes" : "Ih",
     "No" : "Uhu",
     "None" : "Ula d yiwen",
