@@ -61,6 +61,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "예약 링크를 클립보드에 복사하지 못했습니다",
     "Preview" : "미리 보기",
     "Copy link" : "링크 복사",
+    "Duplicate" : "복제",
     "Edit" : "수정",
     "Delete" : "삭제",
     "Appointment schedules" : "약속 일정",
@@ -70,8 +71,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "달력 \"{calendar}\" 활성화",
     "Enable untitled calendar" : "제목 없는 달력 활성화",
     "An error occurred, unable to change visibility of the calendar." : "오류가 발생하여 달력의 공개 설정을 변경할 수 없습니다.",
+    "Calendar link copied to clipboard." : "달력의 링크를 클립보드에 복사했습니다.",
+    "Calendar link could not be copied to clipboard." : "달력의 링크를 클립보드에 복사할 수 없습니다.",
     "Untitled calendar" : "제목없는 달력",
     "Shared with you by" : "다음을 이용해 나와 공유됨 : ",
+    "Copy public link" : "공개 링크 복사",
     "Edit and share calendar" : "달력 편집 및 공유",
     "Edit calendar" : "달력 편집",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["{countdown}초 후 달력 공유 해제"],
@@ -88,8 +92,6 @@ OC.L10N.register(
     "Creating subscription …" : "구독 생성 ...",
     "Add public holiday calendar" : "공개 휴일 달력 추가",
     "Add custom public calendar" : "사용자 지정 공개 달력 추가",
-    "Calendar link copied to clipboard." : "달력의 링크를 클립보드에 복사했습니다.",
-    "Calendar link could not be copied to clipboard." : "달력의 링크를 클립보드에 복사할 수 없습니다.",
     "Copy subscription link" : "구독 링크 복사",
     "Copying link …" : "링크 복사중 …",
     "Copied link" : "링크 복사됨",
@@ -120,7 +122,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "삽입 코드를 클립보드에 복사할 수 없음",
     "Unpublishing calendar failed" : "달력 공개 중단 실패",
     "Share link" : "링크 공유",
-    "Copy public link" : "공개 링크 복사",
     "Send link to calendar via email" : "이메일로 달력 링크 보내기",
     "Enter one address" : "주소 입력",
     "Sending email …" : "이메일로 보내는중 …",
@@ -201,6 +202,7 @@ OC.L10N.register(
     "Create appointment schedule" : "약속 일정 생성",
     "Edit appointment schedule" : "약속 일정 수정",
     "Update" : "업데이트",
+    "(copy)" : "(복사)",
     "Appointment name" : "약속 이름",
     "Location" : "위치",
     "Create a Talk room" : "대화방 만들기",
@@ -297,6 +299,7 @@ OC.L10N.register(
     "Accept" : "수락",
     "Decline" : "거절",
     "Tentative" : "예정됨",
+    "Copied to clipboard" : "클립보드로 복사됨",
     "No attendees yet" : "아직 참석자가 없습니다.",
     "Attendees" : "참석자",
     "Remove group" : "그룹 지우기",
@@ -400,9 +403,9 @@ OC.L10N.register(
     "Personal" : "개인",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "자동으로 감지된 귀하의 시간대가 UTC입니다.\n이 웹 브라우저의 보안 설정이 원인일 수 있습니다.\n달력 설정에서 수동으로 시간대를 설정해 주십시오.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "설정된 시간대 ({timezoneId}) 을(를) 찾을 수 없습니다. UTC로 설정됩니다.\n설정에서 시간대를 변경하고 이 문제를 보고해 주십시오.",
+    "Discard changes" : "변경 사항 버리기",
     "Edit event" : "일정 편집",
     "Event does not exist" : "일정이 존재하지 않음",
-    "Duplicate" : "복제",
     "Delete this occurrence" : "이 일정 삭제",
     "Delete this and all future" : "이후 모든 일정 삭제",
     "All day" : "하루 종일",
@@ -411,9 +414,11 @@ OC.L10N.register(
     "_User requires access to your file_::_Users require access to your file_" : ["사용자가 내 파일에 대한 접근을 요구합니다"],
     "Untitled event" : "제목없는 일정",
     "Close" : "닫기",
+    "This event was cancelled" : "이 일정은 취소되었습니다",
     "Title" : "제목",
     "30 min" : "30분",
     "Participants" : "참가자",
+    "Thank you for your response!" : "답변해 주셔서 감사합니다!",
     "Submit" : "제출",
     "Subscribe to {name}" : "{name} 구독",
     "Export {name}" : "{name} 내보내기",
@@ -524,7 +529,6 @@ OC.L10N.register(
     "Successfully appended link to talk room to location." : "위치에 대화방 링크를 성공적으로 추가함",
     "Successfully appended link to talk room to description." : "설명에 대화방 링크를 성공적으로 추가함",
     "Error creating Talk room" : "대화방 생성 오류",
-    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부",
-    "Keyboard shortcuts" : "키보드 단축키"
+    "The visibility of this event in shared calendars." : "공유 달력에서 이 일정의 표시 여부"
 },
 "nplurals=1; plural=0;");
