@@ -18,7 +18,6 @@ OC.L10N.register(
     "%1$s with %2$s" : "%1$s su %2$s",
     "Calendar" : "Kalendorius",
     "Appointments" : "Susitikimai",
-    "%1$s - %2$s" : "%1$s – %2$s",
     "Confirm" : "Patvirtinti",
     "Description:" : "Aprašas:",
     "This confirmation link expires in %s hours." : "Ši patvirtinimo nuoroda baigia galioti po %s val.",
@@ -56,8 +55,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Įjungti kalendorių „{calendar}“",
     "Enable untitled calendar" : "Įjungti kalendorių be pavadinimo",
     "An error occurred, unable to change visibility of the calendar." : "Įvyko klaida, nepavyko pakeisti kalendoriaus matomumo.",
+    "Calendar link copied to clipboard." : "Kalendoriaus nuoroda nukopijuota į iškarpinę.",
+    "Calendar link could not be copied to clipboard." : "Kalendoriaus nuorodos nepavyko nukopijuoti į iškarpinę.",
     "Untitled calendar" : "Kalendorius be pavadinimo",
     "Shared with you by" : "Su jumis bendrina",
+    "Copy public link" : "Kopijuoti viešąją nuorodą",
     "Edit and share calendar" : "Taisyti ir bendrinti kalendorių",
     "Edit calendar" : "Taisyti kalendorių",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Kalendorius nustojamas bendrinti po {countdown} sekundės","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundžių","Kalendorius nustojamas bendrinti po {countdown} sekundės"],
@@ -72,8 +74,6 @@ OC.L10N.register(
     "New calendar with task list" : "Naujas kalendorius su užduočių sąrašu",
     "New subscription from link (read-only)" : "Nauja prenumerata iš nuorodos (tik skaitymui)",
     "Creating subscription …" : "Kuriama prenumerata…",
-    "Calendar link copied to clipboard." : "Kalendoriaus nuoroda nukopijuota į iškarpinę.",
-    "Calendar link could not be copied to clipboard." : "Kalendoriaus nuorodos nepavyko nukopijuoti į iškarpinę.",
     "Copy subscription link" : "Kopijuoti prenumeratos nuorodą",
     "Copying link …" : "Kopijuojama nuoroda…",
     "Copied link" : "Nuoroda nukopijuota",
@@ -102,7 +102,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Įterpimo kodo nepavyko nukopijuoti į iškarpinę.",
     "Unpublishing calendar failed" : "Nepavyko paskelbti kalendoriaus",
     "Share link" : "Viešinio nuoroda",
-    "Copy public link" : "Kopijuoti viešąją nuorodą",
     "Send link to calendar via email" : "Siųsti el. paštu nuorodą į kalendorių",
     "Enter one address" : "Įveskite vieną adresą",
     "Sending email …" : "Siunčiamas el. laiškas…",
@@ -177,6 +176,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "Viešas – rodomas profilio puslapyje",
     "Private – only accessible via secret link" : "Privatus – pasiekiamas tik per slaptą nuorodą",
     "Update" : "Atnaujinti",
+    "(copy)" : "(kopija)",
     "Location" : "Vieta",
     "Description" : "Aprašas",
     "Visibility" : "Matomumas",
@@ -243,6 +243,7 @@ OC.L10N.register(
     "Accept" : "Priimti",
     "Decline" : "Atmesti",
     "Tentative" : "Preliminarus",
+    "Copied to clipboard" : "Nukopijuota į iškarpinę",
     "No attendees yet" : "Kol kas kviestinių nėra",
     "Attendees" : "Kviestiniai",
     "Remove group" : "Šalinti grupę",
@@ -329,6 +330,7 @@ OC.L10N.register(
     "Personal" : "Asmeniniai",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "Automatinis laiko juostos aptikimas nustatė, kad jūsų laiko juosta yra UTC.\nTaip, greičiausiai, yra dėl jūsų saityno naršyklės saugos priemonių.\nKalendoriaus nustatymuose prašome rankiniu būdu nusistatyti laiko juostą.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Jūsų konfigūruota laiko juosta ({timezoneId}) nerasta. Grįžtama į UTC.\nPrašome nustatymuose pakeisti savo laiko juostą ir pranešti apie šią problemą.",
+    "Discard changes" : "Atmesti pakeitimus",
     "Edit event" : "Taisyti įvykį",
     "Event does not exist" : "Įvykio nėra",
     "Delete this occurrence" : "Ištrinti šį pasikartojimą",
@@ -429,6 +431,7 @@ OC.L10N.register(
     "This is an event reminder." : "Tai priminimas apie įvykį.",
     "Appointment not found" : "Susitikimas nerastas",
     "User not found" : "Naudotojas nerastas",
+    "%1$s - %2$s" : "%1$s – %2$s",
     "Hidden" : "Paslėpta",
     "can edit" : "gali redaguoti",
     "Calendar name …" : "Kalendoriaus pavadinimas…",
