@@ -60,6 +60,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Plānotās tikšanās saiti nevarēja ievietot starpliktuvē.",
     "Preview" : "Priekšskatīt",
     "Copy link" : "Ievietot saiti starpliktuvē",
+    "Duplicate" : "Pavairot",
     "Edit" : "Labot",
     "Delete" : "Izdzēst",
     "Create new" : "Izveidot jaunu",
@@ -68,8 +69,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Iespējot kalendāru \"{calendar}\"",
     "Enable untitled calendar" : "Iespējot kalendāru bez nosaukuma ",
     "An error occurred, unable to change visibility of the calendar." : "Atgadījās kļūda, nevar mainīt kalendāra redzamību.",
+    "Calendar link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
+    "Calendar link could not be copied to clipboard." : "Kalendāra saiti nevarēja ievietot starpliktuvē.",
     "Untitled calendar" : "Kalendārs bez nosaukuma",
     "Shared with you by" : "Koplietots ar Jums",
+    "Copy public link" : "Ievietot publisko saiti starpliktuvē",
     "Edit and share calendar" : "Labot un koplietot kalendāru",
     "Edit calendar" : "Labot kalendāru",
     "An error occurred, unable to create the calendar." : "Atgadījās kļūda, nevar izveidot kalendāru.",
@@ -84,8 +88,6 @@ OC.L10N.register(
     "Creating subscription …" : "Izveido abonementu ...",
     "Add public holiday calendar" : "Pievienot publisku brīvdienu kalendāru",
     "Add custom public calendar" : "Pievienot pielāgotu publisko kalendāru",
-    "Calendar link copied to clipboard." : "Kalendāra saite ievietota starpliktuvē.",
-    "Calendar link could not be copied to clipboard." : "Kalendāra saiti nevarēja ievietot starpliktuvē.",
     "Copy subscription link" : "Ievietot abonēšanas saiti starpliktuvē",
     "Copying link …" : "Saite tiek ievietota starpliktuvē ...",
     "Copied link" : "Kopēta saite",
@@ -115,7 +117,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Iegulšanas kodu nevarēja ievietot starpliktuvē.",
     "Unpublishing calendar failed" : "Neizdevās atcelt kalendāra publicēšanu",
     "Share link" : "Koplietot saiti",
-    "Copy public link" : "Ievietot publisko saiti starpliktuvē",
     "Send link to calendar via email" : "Nosūtīt saiti kalendāra saiti e-pastā",
     "Enter one address" : "Ievadiet vienu adresi",
     "Sending email …" : "Sūta e-pastu ...",
@@ -218,7 +219,6 @@ OC.L10N.register(
     "Successfully added Talk conversation link to location." : "Talk sarunas saite sekmīgi pievienota atrašanās vietai.",
     "Successfully added Talk conversation link to description." : "Talk sarunas saite sekmīgi pievienota aprakstam.",
     "Failed to apply Talk room." : "Neizdevās pielietot Talk istabu.",
-    "Add Talk conversation" : "Pievienot Talk sarunu",
     "Select conversation" : "Atlasīt sarunu",
     "at" : "plkst.",
     "before at" : "pirms ",
@@ -278,6 +278,7 @@ OC.L10N.register(
     "Accept" : "Pieņemt",
     "Decline" : "Noraidīt",
     "Tentative" : "Mēģinājums",
+    "Copied to clipboard" : "Nokopēts starpliktuvē",
     "No attendees yet" : "Vēl nav dalībnieku",
     "Attendees" : "Dalībnieki",
     "Remove group" : "Noņemt grupu",
@@ -359,9 +360,9 @@ OC.L10N.register(
     "Personal" : "Personīgs",
     "Edit event" : "Labot notikumu",
     "Event does not exist" : "Notikums nepastāv",
-    "Duplicate" : "Pavairot",
     "Delete this occurrence" : "Izdzēst šo notikumu",
     "All day" : "Visas dienas",
+    "Add Talk conversation" : "Pievienot Talk sarunu",
     "Managing shared access" : "Koplietotās piekļuves pārvaldība",
     "Deny access" : "Liegt piekļuvi",
     "Invite" : "Uzaicināt",
@@ -471,7 +472,6 @@ OC.L10N.register(
     "Show keyboard shortcuts" : "Rādīt tastatūras saīsnes taustiņus",
     "{invitedCount} invited, {confirmedCount} confirmed" : "{invitedCount} uzaicināti, {confirmedCount} apstiprinājuši",
     "Error creating Talk room" : "Notika kļūda, veidojot tērzēšanas istabu",
-    "The visibility of this event in shared calendars." : "Šī notikuma redzamība koplietotos kalendāros.",
-    "Keyboard shortcuts" : "Tastatūras saīsnes"
+    "The visibility of this event in shared calendars." : "Šī notikuma redzamība koplietotos kalendāros."
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
