@@ -83,8 +83,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Овозможи календар \"{calendar}\"",
     "Enable untitled calendar" : "Овозможи неименуван календар",
     "An error occurred, unable to change visibility of the calendar." : "Настана грешка, неможе да се промени видливоста на календарот.",
+    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
+    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
     "Untitled calendar" : "Неименуван календар",
     "Shared with you by" : "Споделено со вас од",
+    "Copy public link" : "Копирај јавен линк",
     "Edit and share calendar" : "Уреди и сподели календар",
     "Edit calendar" : "Уреди календар",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Отстранување на споделување на календар за 1 секунда","Отстранување на споделување на календар за {countdown} секунди"],
@@ -101,8 +104,6 @@ OC.L10N.register(
     "Creating subscription …" : "Креирање претплата  …",
     "Add public holiday calendar" : "Додади календар со државни празници",
     "Add custom public calendar" : "Додади сопствен јавен календар",
-    "Calendar link copied to clipboard." : "Линк до календарот е копиран во клипборд.",
-    "Calendar link could not be copied to clipboard." : "Линк до календарот неможе да се копира во клипборд.",
     "Copy subscription link" : "Копирај линк за претплата",
     "Copying link …" : "Копирање линк …",
     "Copied link" : "Линкот е копиран",
@@ -135,7 +136,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Кодот за вградување неможе да се копира во клипборд.",
     "Unpublishing calendar failed" : "Неуспешно од-објавување на календар",
     "Share link" : "Сподели линк",
-    "Copy public link" : "Копирај јавен линк",
     "Send link to calendar via email" : "Испрати линк до календарот преку е-пошта",
     "Enter one address" : "Внеси една адреса",
     "Sending email …" : "Испраќање е-пошта …",
@@ -506,7 +506,7 @@ OC.L10N.register(
     "Show unscheduled tasks" : "Прикажи незададени задачи",
     "Unscheduled tasks" : "Нездадени задачи",
     "Availability of {displayName}" : "Достапност на {displayName}",
-    "Discard event" : "Отфрли настан",
+    "Discard changes" : "Орфрли промени",
     "Edit event" : "Уреди го настанот",
     "Event does not exist" : "Настанот не постои",
     "Delete this occurrence" : "Избришете ја оваа можност",
@@ -524,6 +524,7 @@ OC.L10N.register(
     "Untitled event" : "Неименуван настан",
     "Close" : "Затвори",
     "Modifications will not get propagated to the organizer and other attendees" : "Измените нема да бидат применети кај организаторот и другите учесници",
+    "This event was cancelled" : "Овој настан беше откажан",
     "Meeting proposals overview" : "Преглед на предлози за состаноци",
     "Edit meeting proposal" : "Измени предлог за состанок",
     "Create meeting proposal" : "Креирај предлог за состанок",
