@@ -30,6 +30,7 @@ OC.L10N.register(
     "Edit" : "Modificar",
     "Delete" : "Suprimir",
     "Untitled calendar" : "Calendièr sens nom",
+    "Copy public link" : "Copiar lo ligam public",
     "Calendars" : "Calendièrs",
     "Add new" : "Apondre novèl",
     "New calendar" : "Calendièr novèl",
@@ -44,7 +45,6 @@ OC.L10N.register(
     "Internal link" : "Ligam intèrn",
     "Copy internal link" : "Copiar lo ligam intèrn",
     "Share link" : "Partejar lo ligam",
-    "Copy public link" : "Copiar lo ligam public",
     "Copied code" : "Còdi copiat",
     "Could not copy code" : "Se poguèt pas copiar lo còdi",
     "Delete share link" : "Suprimir lo ligam de partatge",
@@ -65,6 +65,7 @@ OC.L10N.register(
     "Actions" : "Accions",
     "or" : "o",
     "General" : "Generals",
+    "Appearance" : "Aparéncia",
     "Editing" : "Edicion",
     "0 minutes" : "0 minuta",
     "Update" : "Metre a jorn",
@@ -109,6 +110,7 @@ OC.L10N.register(
     "Accept" : "Acceptar",
     "Decline" : "Declinar",
     "Tentative" : "Provisòri",
+    "Copied to clipboard" : "Copiat dins lo cartabèu",
     "Attendees" : "Convidats",
     "Remove group" : "Suprimir lo grop",
     "Remove color" : "Suprimir la color",
@@ -186,7 +188,6 @@ OC.L10N.register(
     "User not found" : "Utilizaire pas trobat",
     "Hidden" : "Amagat",
     "can edit" : "pòt modificar",
-    "Show weekends" : "Monstrar las dimenjadas",
-    "Keyboard shortcuts" : "Acorchis de clavièr"
+    "Show weekends" : "Monstrar las dimenjadas"
 },
 "nplurals=2; plural=(n > 1);");
