@@ -61,6 +61,7 @@ OC.L10N.register(
     "Appointment link could not be copied to clipboard" : "Linkul programării nu a putut fi copiat în clipboard",
     "Preview" : "Previzualizare",
     "Copy link" : "Copiază link",
+    "Duplicate" : "Duplicat",
     "Edit" : "Editează",
     "Delete" : "Șterge",
     "Create new" : "Crează nou",
@@ -69,8 +70,11 @@ OC.L10N.register(
     "Enable calendar \"{calendar}\"" : "Activează calendarul \"{calendar}\"",
     "Enable untitled calendar" : "Activează calendarul fără nume",
     "An error occurred, unable to change visibility of the calendar." : "A apărut o eroare, nu se poate schimba vizibilitatea calendarului.",
+    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
+    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
     "Untitled calendar" : "Calendar nedenumit",
     "Shared with you by" : "Partajat cu tine de",
+    "Copy public link" : "Copiză link-ul public",
     "Edit and share calendar" : "Editează și partajează calendarul",
     "Edit calendar" : "Editare calendar",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Oprirea partajării calendarului in {countdown} secundă","Oprirea partajării calendarului în {countdown} secunde","Oprirea partajării calendarului în {countdown} de secunde"],
@@ -86,8 +90,6 @@ OC.L10N.register(
     "New subscription from link (read-only)" : "Abonament nou folosind un link (doar citirea calendarului)",
     "Creating subscription …" : "Se creează abonamentul ...",
     "Add public holiday calendar" : "Adaugă calendar de sărbători",
-    "Calendar link copied to clipboard." : "Linkul către calendar a fost copiat în clipboard.",
-    "Calendar link could not be copied to clipboard." : "Linkul către calendar nu a putut fi copiat în clipboard.",
     "Copy subscription link" : "Copiază linkul abonamentului",
     "Copying link …" : "Copiază link ...",
     "Copied link" : "Link copiat",
@@ -117,7 +119,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Codul nu a putut fi copiat in clipboard.",
     "Unpublishing calendar failed" : "Retragerea calendarului a eşuat",
     "Share link" : "Partajază legătură",
-    "Copy public link" : "Copiză link-ul public",
     "Send link to calendar via email" : "Trimite link-ul către calendar folosind email",
     "Enter one address" : "Introdu o adresă",
     "Sending email …" : "Email-ul se trimite ...",
@@ -279,6 +280,7 @@ OC.L10N.register(
     "Accept" : "Accept",
     "Decline" : "Refuză",
     "Tentative" : "Tentativă",
+    "Copied to clipboard" : "Copiat în clipboard",
     "No attendees yet" : "Nu exista participați încă",
     "Attendees" : "Participanți",
     "Remove group" : "Înlătură grupul",
@@ -378,9 +380,9 @@ OC.L10N.register(
     "Personal" : "Personal",
     "The automatic time zone detection determined your time zone to be UTC.\nThis is most likely the result of security measures of your web browser.\nPlease set your time zone manually in the calendar settings." : "A fost detectată automat zona de timp ca fiind UTC.\nProbabil ca măsura de securitate în cadrul browserului.\nSetați zona de timp manual în setările Calendar.",
     "Your configured time zone ({timezoneId}) was not found. Falling back to UTC.\nPlease change your time zone in the settings and report this issue." : "Zona de timp ({timezoneId}) nu există. Se revenire la UTC.\nModificați zona de timp în setări și raportați această problemă.",
+    "Discard changes" : "Anulează modificările",
     "Edit event" : "Modifică eveniment",
     "Event does not exist" : "Evenimentul nu există",
-    "Duplicate" : "Duplicat",
     "Delete this occurrence" : "Șterge această poziție",
     "Delete this and all future" : "Șterge aceasta și toate viitoare",
     "All day" : "Toată ziua",
@@ -391,6 +393,7 @@ OC.L10N.register(
     "_Attachment requires shared access_::_Attachments requiring shared access_" : ["Atașament care necesită acces partajat","Atașamente care necesită acces partajat","Atașamente care necesită acces partajat"],
     "Untitled event" : "Eveniment fără titlu",
     "Close" : "Închide",
+    "This event was cancelled" : "Acest eveniment a fost anulat",
     "Title" : "Titlu",
     "Participants" : "Participanți",
     "Submit" : "Trimite",
@@ -505,7 +508,6 @@ OC.L10N.register(
     "Successfully appended link to talk room to location." : "S-a adăugat cu succes locației linkul la camera Talk.",
     "Successfully appended link to talk room to description." : "S-a adăugat cu succes descrierii linkul la camera Talk.",
     "Error creating Talk room" : "Camera Talk nu a putut fi creată",
-    "The visibility of this event in shared calendars." : "Vizibilitatea acestui eveniment în calendarele partajate.",
-    "Keyboard shortcuts" : "Scurtături din tastatură"
+    "The visibility of this event in shared calendars." : "Vizibilitatea acestui eveniment în calendarele partajate."
 },
 "nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
