@@ -22,7 +22,6 @@ OC.L10N.register(
     "Appointments" : "Các lịch hẹn ",
     "Schedule appointment \"%s\"" : "Lên lịch lịch hẹn \"%s\"",
     "Schedule an appointment" : "Lên lịch một lịch hẹn",
-    "%1$s - %2$s" : "%1$s-%2$s",
     "Prepare for %s" : "Chuản bị cho %s",
     "Follow up for %s" : "Diễn tiến cho %s",
     "Dear %s, please confirm your booking" : "%s thân ái, vui lòng xác nhận lịch đặt hẹn của bạn",
@@ -63,7 +62,10 @@ OC.L10N.register(
     "Appointment schedules" : "Lên lịch hẹn",
     "Create new" : "Tạo mới",
     "An error occurred, unable to change visibility of the calendar." : "Một lỗi đã xảy ra, không thể thay đổi tính hiển thị của lịch.",
+    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
+    "Calendar link could not be copied to clipboard." : "Liên kết của lịch không thể sao chép vào bảng tạm.",
     "Untitled calendar" : "Lịch không tiêu đề",
+    "Copy public link" : "Sao chép liên kết công khai",
     "_Unsharing the calendar in {countdown} second_::_Unsharing the calendar in {countdown} seconds_" : ["Đang gỡ chia sẻ của lịch trong {countdown} giây"],
     "_Deleting the calendar in {countdown} second_::_Deleting the calendar in {countdown} seconds_" : ["Đang xóa lịch trong {countdown} giây"],
     "An error occurred, unable to create the calendar." : "Một lỗi đã xảy ra, không thẻ tạo lịch.",
@@ -76,8 +78,6 @@ OC.L10N.register(
     "New calendar with task list" : "Lịch mới với danh sách nhiệm vụ",
     "New subscription from link (read-only)" : "Đăng kí theo dõi mới từ liên kết (Chỉ-đọc)",
     "Creating subscription …" : "Đang tạo đăng kí theo dõi mới  …",
-    "Calendar link copied to clipboard." : "Liên kết của lịch đã được sao chép vào bảng tạm.",
-    "Calendar link could not be copied to clipboard." : "Liên kết của lịch không thể sao chép vào bảng tạm.",
     "Copy subscription link" : "Sao chép liên kết theo dõi ",
     "Copying link …" : "Sao chép liên kết  ...",
     "Copied link" : "Liên kết đã được sao chép",
@@ -102,7 +102,6 @@ OC.L10N.register(
     "Embed code could not be copied to clipboard." : "Mã nhúng không thể được sao chép vào bảng tạm.",
     "Unpublishing calendar failed" : "Gỡ công khai cho lịch thất bại",
     "Share link" : "Liên kết chia sẽ",
-    "Copy public link" : "Sao chép liên kết công khai",
     "Send link to calendar via email" : "Gửi liên kết đến lịch thông qua thư điện tử",
     "Enter one address" : "Điền vào môt địa chỉ",
     "Sending email …" : "Đang gửi email ...",
@@ -167,6 +166,7 @@ OC.L10N.register(
     "Public – shown on the profile page" : "Công cộng - Được hiển thị công khai trên trang thông tin cá nhân",
     "Private – only accessible via secret link" : "Riêng tư - Chỉ có thể truy cập thông qua liên kết bí mật",
     "Update" : "Cập nhật",
+    "(copy)" : "(sao chép)",
     "Location" : "Vị trí",
     "Description" : "Mô tả",
     "Visibility" : "Hiển thị",
@@ -242,6 +242,7 @@ OC.L10N.register(
     "Accept" : "Đồng ý",
     "Decline" : "Từ chối",
     "Tentative" : "Chưa chắc chắn",
+    "Copied to clipboard" : "Đã sao chép vào bộ nhớ tạm",
     "No attendees yet" : "Chưa có giờ tham gia",
     "Attendees" : "Người tham gia",
     "Remove group" : "Xóa nhóm",
@@ -343,6 +344,7 @@ OC.L10N.register(
     "Invite" : "Mời",
     "Untitled event" : "Sự kiện không tiêu đề",
     "Close" : "Đóng",
+    "Selected" : "Đã chọn",
     "Title" : "Tên",
     "Participants" : "Người tham gia",
     "Submit" : "Gửi",
@@ -431,6 +433,7 @@ OC.L10N.register(
     "Imported {filename}" : " {filename} đã được nhập",
     "Appointment not found" : "Không tìm thấy cuộc hẹn",
     "User not found" : "Không tìm thấy người dùng",
+    "%1$s - %2$s" : "%1$s-%2$s",
     "Hidden" : "Ẩn",
     "can edit" : "có thể chỉnh sửa",
     "Automatic ({detected})" : " ({detected}) tự động",
